Module error

Module error 

Resampling error types and the Result alias.

ResampleError is the set of classifiable errors that a [Resampler] implementation reports during processing. rubato runtime errors are wrapped as a string in ResampleError::ResampleFailed to avoid the burden of matching rubato’s #[non_exhaustive] error enum.

Enums

ResampleError
Errors that can arise while validating or resampling audio data.

Type Aliases

Result
Convenience alias used by consumers of this crate.